---
title: One Payment Infra(원 페이먼트 인프라)서비스가 궁금해요!
category: 자주 묻는 질문 (일반 문의) > 일반 문의 > 자주 묻는 질문
tags:
  - 공통
  - 이용요금
searchTags:
  - 요금
  - 과금
  - 원페이먼트인프라
  - Custom
  - Growth
  - free
  - OPI
  - 이용요금
datetime: 2024-11-12T15:00:00.000Z
---

### **One Payment Infra(원 페이먼트 인프라)서비스란 ?**

<Callout content="여러PG를 쉽게 연동하여 언제든 결제 오너십을 가질 수 있는 환경을 만드는 
포트원의 핵심가치를 반영한 서비스 입니다.
결제부터 정산까지 단 한 줄의 코드 연동으로 올인원 결제 인프라를 구축할 수 있는 서비스입니다." />

- 포트원 고객이 더 완벽한 결제 오너십을 가실 수 있도록 여러 PG 운영 효율화를 위한 다양한 기능(결제 데이터 분석, PG거래대사, 빌링결제, 스마트라우팅)을 추가적으로 함께 제공할 예정입니다.

* **One Payment Infra 기능 알아보기**



- **통합관리자 페이지**\
  \- PG통합 관리자 페이지 \
  \- 다양한 PG사의 결제 내역을 한번에 관리 가능 \
  \- 결제 상태 취소와 환불 처리 서비스, 현금영수증 발행 및 관리서비스 제공

* **스마트라우팅**\
  \- ON/OFF  스위치 기능으로 개발자 없이 결제 트래픽 분산  \
  \- 장애 인지 후 10초 이내로 즉각 대응 가능\
  ( 자체 구축은 대응까지 평균 1시간 소요)

- **빌링결제**\
  \- 여러 개 빌링키를 통합 관리 할 수 있는 슈퍼빌링키 제공\
  \- 통합 결제 내역 확인 및 실패 건에 대한 재예약/재시도 등 빌링결제 관리 기능 제공

* **PG거래대사**\
  \- 여러 PG 정산 데이터를 한곳에서 관리 가능\
  \- 주문 정보와 거래 내역(승인, 취소, 환불)일치 여부등 거래대사 가능

- **결제 데이터 분석**\
  \- 결제 트렌드 및 결제 수단 우선순위 등 매출 성과 분석 가능\
  \- 결제 전환율 분석을 통해 개선 인사이트 도출

<Callout title="서비스 자세히 알아보러 가기 ↗" />

## 서비스 이용요금 안내



- 유료화 대상: 월 순 거래액 5,000만 원 이상 고객사

<Indent level="1">

- 더 나은 결제 안정성과 인프라를 제공하기 위해 월 순 거래액 5,000만원 이상인 경우, 자동으로 Growth 플랜으로 전환되며 유료 플랜이 적용됩니다.

</Indent>

- 유료 요금제 기준: 순 거래액 기준에 따른 구간별 고정 금액 (VAT별도)

<Indent level="1">

- 5천만 원 미만 : Free
- 5천만 원 이상 \~ 1억 원 미만 : 10만 원
- 1억 원 이상 \~ 5억 원 미만 : 30만 원
- 5억 원 이상 : 50만 원

</Indent>

- 요금 청구 기준: 매월 1일에서 말일까지 발생한 사용량에 대해 다음 달 1일 청구 

<Indent level="1">

- (예시) 11월 1일\~ 11월 30일 승인 거래 건 → 12월 1일 청구서 발행
- 월 순 거래액\* 3천만 원 도달 시, 유료화 적용 사전 안내를 위한 메일이 발송됩니다.\
  \*월 순 거래액 : 월 초 \~ 월 말일까지 발생한 총 거래액 - 동 기간 내 취소/환불액

</Indent>

- 요금 청구 및 결제 절차 안내

<Indent level="1">

- 전월 사용량을 기준으로 당월 1일에 청구서를 결제 담당자 이메일로 발송합니다. 
- 당월  5일까지 서비스 이용 요금에 이의가 있는 경우 문의를 할 수 있는 이의 제기 기간을 제공합니다.
- 당월 10일 오전 10시, 청구된 요금이 등록된 카드를 통해 자동적으로 결제가 진행됩니다

</Indent>

- 결제 형태

<Indent level="1">

- 결제 형태는 월간 결제, 연간 결제가 있습니다.
- 월간 결제 및 연간 결제는 모두 카드 등록을 통해 결제가 가능합니다.

</Indent>

<Indent level="2">

- 월간 결제
  - 전월 사용량에 대한 후불 청구로 결제가 발생합니다.
- 연간 결제
  - 신청 가능 대상자 : 전월 순거래액 5000만원 이상인 고객사
  - 연 결제를 진행하기 위해 사용량 측정이 필요하므로 전월 유료화 고객 대상자들에 한해 신청이 가능합니다.
  - 연간 결제는 콘솔 - 요금 및 결제 메뉴에서 신청이 가능합니다.
  - 연간 결제 진행 시 10% 할인을 적용 받을 수 있습니다.

</Indent>

- **결제 수단 등록 안내**

<Indent level="1">

- 포트원 콘솔에 접속하여 카드 정보 및 결제 정보를 등록해 주세요. \
  📌경로: 관리자콘솔 접속 → 요금 및 결제 메뉴 클릭 → 결제카드 등록 \
  (계정 권한이 Admin, Owner 인 경우에만 카드 등록 가능)
- 카드는 개인 및 법인카드 모두 사용 가능합니다.
- 결제 진행 일자에 유효한 결제 수단이 등록되어 있어야 하며 정상적으로 결제가 이루어지지 않는 경우, 서비스 제한이 있을 수 있습니다.

</Indent>



<Callout title="카드 등록하러 가기 ↗" />

### **💡 FAQ**

One Payment Infra 요금제에 대해 궁금해 하실 내용을 정리했습니다.

<Highlight text="Q. 순 거래액 기준은 어떻게 책정되는 것일까요?" />

순 거래액은 사용 기간 내에 발생한 전체 거래액(테스트 제외)에서 동 기간 내에 발생한 취소/환불액을 제외한 금액입니다.

- (예시) 9월에 결제가 되었지만 10월에 취소/환불된 거래 건 = 10월 취소 금액에 포함
- (예시) 10월에 결제 되어 10월 이내에 취소/환불된 거래 건 = 10월 취소 금액에 포함

<Highlight text="Q. 사용량 기준은 어떻게 되나요?" />

사용량은 매월 1일 00:00:00에서 말일 23:59:59까지 발생한 순 거래액으로 책정합니다. \
전월 사용량 기준으로 당월 요금이 산정되며 매월 요금은 사용량에 따라 변동됩니다. \
서비스 이용 시, 월 순 거래액 5천만 원 미만인 경우 무료로 사용 가능합니다.

<Highlight text="Q.기준이 되는 월 순 거래액을 어떻게 확인할 수 있나요?" />

포트원 관리자 콘솔 > 요금 및 결제 메뉴를 통해 실시간 사용량을 확인하거나, 매월 1일 발송되는 청구서를 통해 확인이 가능합니다.

<Highlight text="Q. 사용 가능한 결제수단은 어떤 것들이 있을까요?" />

결제수단은 카드만 가능하며 개인카드 및 법인카드 모두 사용할 수 있으나, 해외 카드 결제는 지원하지 않습니다.

<Highlight text="Q. 본인인증 서비스만 사용 중이어도 과금이 되나요?" />

포트원을 통해 본인인증만 연동해서 사용하고, 별도 결제 연동이 되지 않았다면 요금이 발생하지 않습니다.

<Highlight text="Q. 결제는 어떻게 진행되나요?" />

**\[결제 일정 및 청구서 발송]**\
당월 거래 건수를 기준으로 다음 달 1일 청구서가 발송되고, 10일에 결제가 진행됩니다. \
결제 진행 일자에 유효한 결제 수단이 등록되어 있어야 합니다.\
\[예시] 11월 1일 \~ 11월 30일 승인 거래 건 → 12월 1일 청구서 발행 → 12월 10일 자동결제

**\[결제 방식]** \
결제는 정기결제 방식으로 진행됩니다. \
결제수단은 카드만 가능하며 개인카드 및 법인카드 모두 사용할 수 있습니다.

**\[결제 수단 등록]**\
관리자콘솔 접속 → 요금 및 결제 메뉴 클릭 → 결제카드 등록 \
(계정 권한이 Admin, Owner 인 경우에만 카드 등록 가능)\
[카드 등록 하러가기 ↗](https://admin.portone.io/auth/signin?redirect=subscription)

<Highlight text="Q. 환불이 가능한가요?" />

- 월간결제의 경우, 사용량에 대한 후불 청구이기 때문에 환불 및 취소는 진행하지 않습니다.
- 연결제의 경우 선납 이므로 환불 정책이 적용됩니다.
  - 기본적으로 환불은 할인되기 전 금액으로 사용 금액을 책정하여 남은 금액이 환불됩니다.
    - ex) 30만원 구간의 경우 "기고객 연결제 30% 할인"을 받고 7개월 사용했을 경우
      - 환불 금액 : 연 결제 금액(21만\_12개월) - 사용 금액(30만\_7개월) =   <Highlight text="환불가능금액 : 42만원" />
      - 다만, 환불 금액을 계산했을 때 마이너스가 발생하는 경우 차액을 받는 것이 아닌 0원으로 처리가 됩니다.
    - ex) 30만원 구간의 경우 “연결제 10% 할인"을 받고 11개월 사용했을 경우
      - 환불 금액 : 연 결제 금액(27만\_12개월) - 사용 금액(30만\_11개월) = <Highlight text="- 6만원 이나 환불가능금액 : 0원" /> 
  - 연결제를 진행할 경우 6개월 동안 필수로 사용해야 하며, 6개월 이내 환불 요청을 하는 경우 환불 금액은 6개월을 차감한 금액으로 계산이 됩니다
    - ex) 30만원 구간의 경우 "기고객 연결제 30% 할인"을 받고 4개월 사용했을 경우
      - 환불 금액 : 연 결제 금액(21만\_12개월) - 사용 금액(30만\_6개월) = <Highlight text="환불가능금액 : 72만원" />

<Callout title="One Payment Infra 상세내용 보러가기 ↗" />
